<?php

namespace Drupal\site_version;

/**
 * Site Version Helper functions.
 */
class SiteVersionHelper {

  /**
   * Get Configuration Name.
   */
  public static function getConfigName() {
    return 'site_version.settings';
  }

  /**
   * Get Configuration Object.
   *
   * @return \Drupal\Core\Config\Config|\Drupal\Core\Config\ImmutableConfig
   *   The configuration object.
   */
  public static function getConfig($editable = FALSE) {
    if ($editable) {
      $config = \Drupal::configFactory()->getEditable(static::getConfigName());
    }
    else {
      $config = \Drupal::config(static::getConfigName());
    }
    return $config;
  }

  /**
   * Get Version details.
   *
   * @return array
   *   Version details
   */
  public static function getVersionDetails() {
    // Get config.
    $config = SiteVersionHelper::getConfig(FALSE);

    $output = [];
    // Update.
    $fields = [
      'version',
      'build',
      'description',
    ];
    foreach ($fields as $field) {
      $output[$field] = $config->get($field);
    }

    return $output;
  }

}
