<?php

namespace Drupal\site_version\Tests;

use Drupal\simpletest\WebTestBase;

/**
 * Test uninstall functionality of Site Version module.
 *
 * @group site_version
 */
class SiteVersionUninstallTest extends WebTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['site_version'];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $permissions = [
      'access administration pages',
      'administer modules',
      'site_version admin',
    ];

    // User to set up site_version.
    $this->admin_user = $this->drupalCreateUser($permissions);
    $this->drupalLogin($this->admin_user);
  }

  /**
   * Tests if the module cleans up the disk on uninstall.
   */
  public function testSiteVersionUninstall() {

    // Uninstall the module.
    $edit = [];
    $edit['uninstall[site_version]'] = TRUE;
    $this->drupalPostForm('admin/modules/uninstall', $edit, $this->t('Uninstall'));
    $this->assertNoText(\Drupal::translation()->translate('Configuration deletions'), 'No configuration deletions listed on the module install confirmation page.');
    $this->drupalPostForm(NULL, NULL, $this->t('Uninstall'));
    $this->assertText($this->t('The selected modules have been uninstalled.'), 'Modules status has been updated.');

  }

}
